| Home | Libraries | People | FAQ | More

## Compilers

This section contains some information about how various compilers work with this library. It is not comprehensive and updated experiences are always welcome. Some effort has been made to suppress unhelpful warnings but it is difficult to achieve this on all systems.

Table 1.9. Supported/Tested Compilers

Platform | Compiler | Has long double support | Notes
--- | --- | --- | ---
Windows | MSVC 7.1 and later | Yes | All tests OK. We aim to keep our headers warning free at level 4 with this compiler.
Windows | Intel 8.1 and later | Yes | All tests OK. We aim to keep our headers warning free at level 4 with this compiler. However, The tests cases tend to generate a lot of warnings relating to numeric underflow of the test data: these are harmless.
Windows | GNU Mingw32 C++ | Yes | All tests OK. We aim to keep our headers warning free with -Wall with this compiler.
Windows | GNU Cygwin C++ | No | All tests OK. We aim to keep our headers warning free with -Wall with this compiler. Long double support has been disabled because there are no native long double C std library functions available.
Windows | Borland C++ 5.8.2 (Developer studio 2006) | No | We have only partial compatibility with this compiler: Long double support has been disabled because the native long double C standard library functions really only forward to the double versions. This can result in unpredictable behaviour when using the long double overloads: for example `sqrtl` applied to a finite value, can result in an infinite result. Some functions still fail to compile, there are no known workarounds at present.
Windows 7/Netbeans 7.2 | Clang 3.1 | Yes | Spot examples OK. Expect all tests to compile and run OK.
Linux | GNU C++ 3.4 and later | Yes | All tests OK. We aim to keep our headers warning free with -Wall with this compiler.
Linux | Clang 3.2 | Yes | All tests OK.
Linux | Intel C++ 10.0 and later | Yes | All tests OK. We aim to keep our headers warning free with -Wall with this compiler. However, The tests cases tend to generate a lot of warnings relating to numeric underflow of the test data: these are harmless.
Linux | Intel C++ 8.1 and 9.1 | No | All tests OK. Long double support has been disabled with these compiler releases because calling the standard library long double math functions can result in a segfault. The issue is Linux distribution and glibc version specific and is Intel bug report #409291. Fully up to date releases of Intel 9.1 (post version l_cc_c_9.1.046) shouldn't have this problem. If you need long double support with this compiler, then comment out the define of BOOST_MATH_NO_LONG_DOUBLE_MATH_FUNCTIONS at line 55 of boost/math/tools/config.hpp. We aim to keep our headers warning free with -Wall with this compiler. However, The tests cases tend to generate a lot of warnings relating to numeric underflow of the test data: these are harmless.
Linux | QLogic PathScale 3.0 | Yes | Some tests involving conceptual checks fail to build, otherwise there appear to be no issues.
Linux | Sun Studio 12 | Yes | Some tests involving function overload resolution fail to build, these issues should be rarely encountered in practice.
Solaris | Sun Studio 12 | Yes | Some tests involving function overload resolution fail to build, these issues should be rarely encountered in practice.
Solaris | GNU C++ 4.x | Yes | All tests OK. We aim to keep our headers warning free with -Wall with this compiler.
HP Tru64 | Compaq C++ 7.1 | Yes | All tests OK.
HP-UX Itanium | HP aCC 6.x | Yes | All tests OK. Unfortunately this compiler emits quite a few warnings from libraries upon which we depend (TR1, Array etc).
HP-UX PA-RISC | GNU C++ 3.4 | No | All tests OK.
Apple Mac OS X, Intel | Darwin/GNU C++ 4.x | Yes | All tests OK.
Apple Mac OS X, PowerPC | Darwin/GNU C++ 4.x | No | All tests OK. Long double support has been disabled on this platform due to the rather strange nature of Darwin's 106-bit long double implementation. It should be possible to make this work if someone is prepared to offer assistance.
Apple Mac OS X, | Clang 3.2 | Yes | All tests expected to be OK.
IBM AIX | IBM xlc 5.3 | Yes | All tests pass except for our fpclassify tests which fail due to a bug in `std::numeric_limits`, the bug effects the test code, not fpclassify itself. The IBM compiler group are aware of the problem.

Table 1.10. Unsupported Compilers

Platform | Compiler
--- | ---
Windows | Borland C++ 5.9.2 (Borland Developer Studio 2007)
Windows | MSVC 6 and 7

If your compiler or platform is not listed above, please try running the regression tests: cd into boost-root/libs/math/test and do a:

    bjam mytoolset

where "mytoolset" is the name of the Boost.Build toolset used for your compiler. The chances are that many of the accuracy tests will fail at this stage - don't panic - the default acceptable error tolerances are quite tight, especially for long double types with an extended exponent range (these cause more extreme test cases to be executed for some functions). You will need to cast an eye over the output from the failing tests and make a judgement as to whether the error rates are acceptable or not.